@@ -4,7 +4,7 @@ use Moose;
 use MooseX::Daemonize::Pid::File;
 use FCGI::Engine::Types;
 
-our $VERSION   = '0.19'; 
+our $VERSION   = '0.20'; 
 our $AUTHORITY = 'cpan:STEVAN';
 
 has 'name' => (
@@ -62,7 +62,9 @@ has 'pid_obj' => (
 
 sub construct_command_line {
     my $self = shift;
-    return ("perl",
+    my $perl = $Config{perlpath};
+    $perl .= $Config{_exe} if $^O ne 'VMS' and $perl !~ /$Config{_exe}$/i;
+    return ($perl,
          ($self->has_additional_args
              ? $self->additional_args
              : ()),
